==> mishkal_hebrew-0.3.5.tar.gz: mishkal_hebrew-0.3.5/examples/phonemize.py <==
"""
Quick Nakdan https://nakdanlive.dicta.org.il
Pro Nakdan https://nakdanpro.dicta.org.il
Manual Nakdan https://www.yo-yoo.co.il/tools/nikud
"""

from mishkal import phonemize

sentences = [
    # "הִיא אָמְרָה לִי",  # Hirik with Yod vowel
    # "מָה קוֹרֶה?",  # Vav with Holam vowel
    # "הוּא קֵרֵחַ",  # Het gnuva
    # "גִ'ירָפָה זַ'רְגּוֹן",  # Geresh
    # "שָׁלוֹם שׂוֹרֵר",  # Shin Sin
    # "לְבִיבָה יְלָדִים שְׁאֵלָה בְּהֵמָה זְעָקוֹת בְּרֹאשׁ גּוֹרְרִים מְצַפְצְפִים מִרְפְּאוֹתֵיהֶם",  # Shva na
    # "בְּרוֹשׁ סְבִיבָה בְּרָגִים שְׁפֵלָה בְּרֵכָה זְנָבוֹת גּוֹרְמִים הָלַכְתְּ וּבְרָכָה",  # Shva nax
    # "אַתָּה חַיָּב לִי 50 שֶׁקֶל וְהַסֵּמֶל הוּא ₪",  # numbers, symbols
    # "כל",  # dictionary
    # "ווֹלְטֶר",  # double vav start
    # "הֲווֹלְטֶר",  # double vav middle
    # "אֶלֶגַנְטִי",  # lookup
    # "כָּל",  # match to one without nikud
    # "יִשְׂרָאֵל הוּקְמָה בִּשְׁנַת 1948",
    # "₪",
    # "מָחָר בְּשָׁעָה 22:00",  # time to word
    # "אוֹרוֹת ווֹלְטֶר ווֹלֶנְטַיְן אֻרְווֹת אוֹרְחִים אָרְבוּ הוֹוֶה וּוּבְּרִים וָו וִי וּוִיקְטוֹר",  # Vavs
    # "לְמַיִם אֱלֹהֵי",
    # "שְׁמַע אָח שֶׁלִּי, תִּרְאֶה. נִרְאֶה לִי שֶׁזֶּה עוֹבֵד!",
    # "גִ'ירָפָה",
    # "יִהְיֶה",
    # "בְּמָה",
    # "בְּיִשְׂרָאֵל.",
    # "אֲוִויר",
    # "לַכִּיווּן",
    # """קִיוּוּ""",
    # "אֻרְווֹת",
    # "וּוִיקְטוֹר",
    # "אֲוִויר",
    # "מְאוּוְרֶרֶת",
    # "טוֹוִים",
    # "מִגְוַון",
    # "הַקַּווְקָז",
    # "בְּסִיוֹוֹן",
    # "צוֹוַחַת",
    # "צוֹוְחִים",
    # "וּוֶנְדֶּר",
    # "וּוַעֲדַת",
    # "שָׁלוֹם",
    # "וּמֶה",
    # "הַתְּרוּמָה",
    # "English",
    # "בַּרִ֫יא",
    # "זֶ֫ה הָיָ֫ה קוֹרֵ֫עַ מִצְּח֫וֹק הֵ֫ם קוֹרְעִ֫ם אוֹתִ֫י",
    # "וּבֽתוֹלְד֫וֹת",
    # "וִירוּשָׁלַיִם",
    # "וְאַתָּה",
    # "אוּרִי",
    # "אַוָּרִי",
    # "וָואלָה",
    # "ווֹלְטֶר",
    # "אוֹרִי",
    # "אֻרִי",
    # "גִּ׳ירָהּ",
    # "גִּ'רַ֫פָה",
    # "זָ'קֵ֫ט",
    # "תַּ'מְבִין",
    # "כֹּחַ",
    # "מֹחַ",
    # "כָּל",
    # "רֵיחַ",
    # "אֶלֶף עֶרֶב",
    # "לִוְיָתָ֫ן",
    # "יִשָּׂשכָר",
    # "יִשָּׂשכָ֫ר",
    # "יַאלְלָה",
    # "אִיָּ֫ר",
    
    # "קוֹרֶה",
    # "אָח",
    # "שְׁמוּרִים",
    # "עֶ֫רֶב",
    # "מַגְנִיבָה",
    # "אוֹפַנַּיִים",
    # "אֵיתָנוּת",
    # "רֵיחַ",
    # "אֵיתָנוּת",
    # "אֵיר֫וֹפָּה",
    "צָהֳרַ֫יִם",
    "דַּוָָר",
    # "עַכְשָׁ֫יו",
    "כׇּל אֶחָד יָכוֹל!",
    # "הַמָּלֵא",
    # "רוּחַ",
    # "אֶנְצִיקְלוֹפֶּ֫דְיָה",
    # 'צַהַ"ל',
    # "שָׁלוֹם",
    # "אֶנְצִיקְלוֹפֶּדְיָה",
    # "אוֹפַנַּייִם @"c
    "קֵרֵחַ",
    # "שָׁלוֹם חֲבֵרִים! מָה שְׁלוֹמְכֶם?",
    "אֶנְצִיקְלוֹפֶּ֫דְיָה",
    "וַאלְלָה",
    "בָּךְ"
]

# TODO: wolter and add to tests


for sentence in sentences:
    phonemes = phonemize(
        sentence, 
        preserve_punctuation=True, 
        use_post_normalize=True, 
        use_expander=True,
        predict_stress=True,
        schema='modern'
    )
    print(phonemes)

==> mishkal_hebrew-0.3.7.tar.gz: mishkal_hebrew-0.3.7/examples/phonemize.py <==
"""
Quick Nakdan https://nakdanlive.dicta.org.il
Pro Nakdan https://nakdanpro.dicta.org.il
Manual Nakdan https://www.yo-yoo.co.il/tools/nikud

uv run examples/phonemize.py
"""

from mishkal import phonemize

sentences = [
    # "הִיא אָמְרָה לִי",  # Hirik with Yod vowel
    # "מָה קוֹרֶה?",  # Vav with Holam vowel
    # "הוּא קֵרֵחַ",  # Het gnuva
    # "גִ'ירָפָה זַ'רְגּוֹן",  # Geresh
    # "שָׁלוֹם שׂוֹרֵר",  # Shin Sin
    # "לְבִיבָה יְלָדִים שְׁאֵלָה בְּהֵמָה זְעָקוֹת בְּרֹאשׁ גּוֹרְרִים מְצַפְצְפִים מִרְפְּאוֹתֵיהֶם",  # Shva na
    # "בְּרוֹשׁ סְבִיבָה בְּרָגִים שְׁפֵלָה בְּרֵכָה זְנָבוֹת גּוֹרְמִים הָלַכְתְּ וּבְרָכָה",  # Shva nax
    # "אַתָּה חַיָּב לִי 50 שֶׁקֶל וְהַסֵּמֶל הוּא ₪",  # numbers, symbols
    # "כל",  # dictionary
    # "ווֹלְטֶר",  # double vav start
    # "הֲווֹלְטֶר",  # double vav middle
    # "אֶלֶגַנְטִי",  # lookup
    # "כָּל",  # match to one without nikud
    # "יִשְׂרָאֵל הוּקְמָה בִּשְׁנַת 1948",
    # "₪",
    # "מָחָר בְּשָׁעָה 22:00",  # time to word
    # "אוֹרוֹת ווֹלְטֶר ווֹלֶנְטַיְן אֻרְווֹת אוֹרְחִים אָרְבוּ הוֹוֶה וּוּבְּרִים וָו וִי וּוִיקְטוֹר",  # Vavs
    # "לְמַיִם אֱלֹהֵי",
    # "שְׁמַע אָח שֶׁלִּי, תִּרְאֶה. נִרְאֶה לִי שֶׁזֶּה עוֹבֵד!",
    # "גִ'ירָפָה",
    # "יִהְיֶה",
    # "בְּמָה",
    # "בְּיִשְׂרָאֵל.",
    # "אֲוִויר",
    # "לַכִּיווּן",
    # """קִיוּוּ""",
    # "אֻרְווֹת",
    # "וּוִיקְטוֹר",
    # "אֲוִויר",
    # "מְאוּוְרֶרֶת",
    # "טוֹוִים",
    # "מִגְוַון",
    # "הַקַּווְקָז",
    # "בְּסִיוֹוֹן",
    # "צוֹוַחַת",
    # "צוֹוְחִים",
    # "וּוֶנְדֶּר",
    # "וּוַעֲדַת",
    # "שָׁלוֹם",
    # "וּמֶה",
    # "הַתְּרוּמָה",
    # "English",
    # "בַּרִ֫יא",
    # "זֶ֫ה הָיָ֫ה קוֹרֵ֫עַ מִצְּח֫וֹק הֵ֫ם קוֹרְעִ֫ם אוֹתִ֫י",
    # "וּבֽתוֹלְד֫וֹת",
    # "וִירוּשָׁלַיִם",
    # "וְאַתָּה",
    # "אוּרִי",
    # "אַוָּרִי",
    # "וָואלָה",
    # "ווֹלְטֶר",
    # "אוֹרִי",
    # "אֻרִי",
    # "גִּ׳ירָהּ",
    # "גִּ'רַ֫פָה",
    # "זָ'קֵ֫ט",
    # "תַּ'מְבִין",
    # "כֹּחַ",
    # "מֹחַ",
    # "כָּל",
    # "רֵיחַ",
    # "אֶלֶף עֶרֶב",
    # "לִוְיָתָ֫ן",
    # "יִשָּׂשכָר",
    # "יִשָּׂשכָ֫ר",
    # "יַאלְלָה",
    # "אִיָּ֫ר",
    
    # "קוֹרֶה",
    # "אָח",
    # "שְׁמוּרִים",
    # "עֶ֫רֶב",
    # "מַגְנִיבָה",
    # "אוֹפַנַּיִים",
    # "אֵיתָנוּת",
    # "רֵיחַ",
    # "אֵיתָנוּת",
    # "אֵיר֫וֹפָּה",
    # "צָהֳרַ֫יִם",
    # "דַּוָָר",
    # "עַכְשָׁ֫יו",
    # "כׇּל אֶחָד יָכוֹל!",
    # "הַמָּלֵא",
    # "רוּחַ",
    # "אֶנְצִיקְלוֹפֶּ֫דְיָה",
    # 'צַהַ"ל',
    # "שָׁלוֹם",
    # "אֶנְצִיקְלוֹפֶּדְיָה",
    # "אוֹפַנַּייִם @"c
    # "קֵרֵחַ",
    # "שָׁלוֹם חֲבֵרִים! מָה שְׁלוֹמְכֶם?",
    # "אֶנְצִיקְלוֹפֶּ֫דְיָה",
    # "וַאלְלָה",
    # "בָּךְ",
    "חֲתֻונָּה",
    "דִּוּ֫וּחַ",
    "שֶׁמְּֽשַׁוֶּ֫קֶת"
]

# TODO: wolter and add to tests

for sentence in sentences:
    phonemes = phonemize(
        sentence, 
        preserve_punctuation=True, 
        use_post_normalize=True, 
        use_expander=True,
        predict_stress=True,
        predict_shva_nah=False,
        schema='modern'
    )
    print(phonemes)
